<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;
use PDF;

class UserController extends Controller
{
    public function submitKYC(Request $request)
    {
        // Validate KYC form data
        $validator = Validator::make($request->all(), [
            'firstname' => 'required|string|max:255',
            'lastname' => 'required|string|max:255',
            // Add validation rules for other KYC fields
            'id_card' => 'required|file|mimes:pdf,jpg,jpeg,png',
            'address_proof' => 'required|file|mimes:pdf,jpg,jpeg,png',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator)->withInput();
        }

        // Save KYC documents
        $user = auth()->user(); // Assuming users are authenticated
        $kycData = $request->except(['_token', 'id_card', 'address_proof']);

        // Save uploaded KYC documents to storage
        $idCardPath = $request->file('id_card')->store('kyc_documents');
        $addressProofPath = $request->file('address_proof')->store('kyc_documents');

        // Update user's KYC information in the database
        $user->update([
            'firstname' => $kycData['firstname'],
            'lastname' => $kycData['lastname'],
            // Update other KYC fields as needed
            'id_card_path' => $idCardPath,
            'address_proof_path' => $addressProofPath,
            'kyc_status' => 'pending', // Set KYC status to pending or any other status
        ]);

        // Generate KYC PDF
        $pdf = PDF::loadView('pdf.kyc', compact('user'));

        // Save the PDF to storage
        $pdfPath = storage_path('app/kyc_documents/'.$user->id.'_kyc.pdf');
        $pdf->save($pdfPath);

        // Attach the PDF path to the user's KYC record or store it as needed

        // Redirect or respond accordingly
        return redirect()->route('user.profile')->with('success', 'KYC submitted successfully!');
    }

    